@@ -82,6 +82,9 @@ elif board_id == ap_board.JETSON_NANO:
 elif board_id == ap_board.CORAL_EDGE_TPU_DEV:
     from adafruit_blinka.board.coral_edge_tpu import *
 
+elif board_id == ap_board.ODROID_C2:
+    from adafruit_blinka.board.odroidc2 import *
+
 elif "sphinx" in sys.modules:
     pass
 
